# [Zope-tests] OK : ZTK 1.0 / Python2.5.5 Linux 64bit

ccomb at free.fr ccomb at free.fr
Wed Feb 2 19:47:45 EST 2011

- Previous message: [Zope-tests] OK : ZTK 1.0 / Python2.6.5 Linux 64bit
- Next message: [Zope-tests] OK : winbot / ZODB_dev py_265_win64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : ZTK 1.0 / Python2.5.5 Linux 64bit
    Build: http://buildbot.afpy.org/ztk1.0/builders/Python2.5.5%20Linux%2064bit/builds/150

    Build Reason: The Nightly scheduler named 'nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://buildbot.afpy.org/ztk1.0/

- Previous message: [Zope-tests] OK : ZTK 1.0 / Python2.6.5 Linux 64bit
- Next message: [Zope-tests] OK : winbot / ZODB_dev py_265_win64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list